function varargout = HindmarschRose(varargin)
% HINDMARSCHROSE MATLAB code for HindmarschRose.fig
%      HINDMARSCHROSE, by itself, creates a new HINDMARSCHROSE or raises the existing
%      singleton*.
%
%      H = HINDMARSCHROSE returns the handle to a new HINDMARSCHROSE or the handle to
%      the existing singleton*.
%
%      HINDMARSCHROSE('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in HINDMARSCHROSE.M with the given input arguments.
%
%      HINDMARSCHROSE('Property','Value',...) creates a new HINDMARSCHROSE or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before HindmarschRose_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to HindmarschRose_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help HindmarschRose

% Last Modified by GUIDE v2.5 16-May-2011 12:41:06

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @HindmarschRose_OpeningFcn, ...
                   'gui_OutputFcn',  @HindmarschRose_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before HindmarschRose is made visible.
function HindmarschRose_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to HindmarschRose (see VARARGIN)

% Choose default command line output for HindmarschRose
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes HindmarschRose wait for user response (see UIRESUME)
% uiwait(handles.figure1);

set(handles.bSlider,'Value', 2.95);
set(handles.ISlider,'Value', 1.24);
set(handles.text1, 'String', num2str(1.25));
set(handles.text2, 'String', num2str(2.95));

params = [get(handles.bSlider, 'Value'), get(handles.ISlider, 'Value'), 0.01 4];
[t, phi] = ode45(@(t,x)hr(t,x,params), [0 2000], [0 0 0]);
tr = 300;
phi = phi(t>tr,:);
t = t(t>tr);
plot3(handles.axes1, phi(:,1), phi(:,2), phi(:,3));
xlabel('Voltage');
ylabel('Fast var');
zlabel('Slow var');
figure(1);
plot(t,phi(:,1));

% --- Outputs from this function are returned to the command line.
function varargout = HindmarschRose_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on slider movement.
function bSlider_Callback(hObject, eventdata, handles)
% hObject    handle to bSlider (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider
set(handles.text1, 'String', num2str(get(handles.ISlider,'Value')));
set(handles.text2, 'String', num2str(get(handles.bSlider,'Value')));

params = [get(handles.bSlider, 'Value'), get(handles.ISlider, 'Value'), 0.01 4];
[t, phi] = ode45(@(t,x)hr(t,x,params), [0 2000], [0 0 0]);
tr = 300;
phi = phi(t>tr,:);
t = t(t>tr);
plot3(handles.axes1, phi(:,1), phi(:,2), phi(:,3));
xlabel('Voltage');
ylabel('Fast var');
zlabel('Slow var');
figure(1);
plot(t,phi(:,1));

% --- Executes during object creation, after setting all properties.
function bSlider_CreateFcn(hObject, eventdata, handles)
% hObject    handle to bSlider (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on slider movement.
function ISlider_Callback(hObject, eventdata, handles)
% hObject    handle to ISlider (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider
set(handles.text1, 'String', num2str(get(handles.ISlider,'Value')));
set(handles.text2, 'String', num2str(get(handles.bSlider,'Value')));

params = [get(handles.bSlider, 'Value'), get(handles.ISlider, 'Value'), 0.01 4];
[t, phi] = ode45(@(t,x)hr(t,x,params), [0 2000], [0 0 0]);
tr = 300;
phi = phi(t>tr,:);
t = t(t>tr);
plot3(handles.axes1, phi(:,1), phi(:,2), phi(:,3));
xlabel('Voltage');
ylabel('Fast var');
zlabel('Slow var');
figure(1);
plot(t,phi(:,1));

% --- Executes during object creation, after setting all properties.
function ISlider_CreateFcn(hObject, eventdata, handles)
% hObject    handle to ISlider (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end
